@@ -22,8 +22,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -848,7 +848,7 @@ prefs_changed_callback (MetaPreference pref,
   
   if (pref == META_PREF_NUM_WORKSPACES)
     {
-      /* MateConf doesn't provide timestamps, but luckily update_num_workspaces
+      /* GSettings doesn't provide timestamps, but luckily update_num_workspaces
        * often doesn't need it...
        */
       guint32 timestamp = 
@@ -1272,8 +1272,8 @@ meta_screen_ensure_tab_popup (MetaScreen      *screen,
     {
       MetaWindow *window;
       MetaRectangle r;
-      GdkPixbuf *win_pixbuf;
-      int width, height;
+      GdkPixbuf *win_pixbuf = NULL;
+      int width = 0, height = 0;
 
       window = tmp->data;
       
@@ -1281,8 +1281,8 @@ meta_screen_ensure_tab_popup (MetaScreen      *screen,
       entries[i].title = window->title;
 
       /* Only get the pixbuf if the user does NOT have 
-         /apps/marco/general/compositing_fast_alt_tab set to true 
-         in mateconf. There is an obvious lag when the pixbuf is
+         compositing-fast-alt-tab-set to true 
+         in GSettings. There is an obvious lag when the pixbuf is
          retrieved. */
       if (!meta_prefs_get_compositing_fast_alt_tab())
         win_pixbuf = get_window_pixbuf (window, &width, &height);
