@@ -18,8 +18,8 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  */
 
 #ifndef META_PREFS_H
@@ -62,6 +62,7 @@ typedef enum
   META_PREF_COMPOSITING_MANAGER,
   META_PREF_COMPOSITING_FAST_ALT_TAB,
   META_PREF_RESIZE_WITH_RIGHT_BUTTON,
+  META_PREF_CENTER_NEW_WINDOWS,
   META_PREF_FORCE_FULLSCREEN
 } MetaPreference;
 
@@ -97,10 +98,10 @@ gboolean                    meta_prefs_get_mate_animations   (void);
 
 const char*                 meta_prefs_get_command            (int i);
 
-char*                       meta_prefs_get_mateconf_key_for_command (int i);
+char*                       meta_prefs_get_settings_key_for_command (int i);
 
 const char*                 meta_prefs_get_terminal_command   (void);
-const char*                 meta_prefs_get_mateconf_key_for_terminal_command (void);
+const char*                 meta_prefs_get_settings_key_for_terminal_command (void);
 
 void                        meta_prefs_get_button_layout (MetaButtonLayout *button_layout);
 
@@ -119,6 +120,7 @@ const char* meta_prefs_get_cursor_theme      (void);
 int         meta_prefs_get_cursor_size       (void);
 gboolean    meta_prefs_get_compositing_manager (void);
 gboolean    meta_prefs_get_compositing_fast_alt_tab (void);
+gboolean    meta_prefs_get_center_new_windows  (void);
 gboolean    meta_prefs_get_force_fullscreen  (void);
 
 /**
@@ -130,6 +132,8 @@ void meta_prefs_set_compositing_manager (gboolean whether);
 
 void meta_prefs_set_compositing_fast_alt_tab (gboolean whether);
 
+void meta_prefs_set_center_new_windows (gboolean whether);
+
 void meta_prefs_set_force_fullscreen (gboolean whether);
 
 /* XXX FIXME This should be x-macroed, but isn't yet because it would be
