@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -2148,15 +2148,19 @@ generate_pixmap (MetaFrames *frames,
   GdkRegion *region;
   GdkPixmap *result;
 
+  /* do not create a pixmap for nonexisting areas */
+  if (rect.width <= 0 || rect.height <= 0)
+  	return NULL;
+
   rectangle.x = rect.x;
   rectangle.y = rect.y;
-  rectangle.width = MAX (rect.width, 1);
-  rectangle.height = MAX (rect.height, 1);
+  rectangle.width = rect.width;
+  rectangle.height = rect.height;
 
   result = gdk_pixmap_new (frame->window,
-                           rectangle.width, rectangle.height, -1);
+                           rect.width, rect.height, -1);
 
-  clear_backing (result, frame->window, rectangle.x, rectangle.y);
+  clear_backing (result, frame->window, rect.x, rect.y);
 
   region = gdk_region_rectangle (&rectangle);
 
